==========================
CMake Python Distributions
==========================

.. image:: https://ci.appveyor.com/api/projects/status/439ila0jk7v6uqrr/branch/master?svg=true
    :target: https://ci.appveyor.com/project/scikit-build/cmake-python-distributions-f3rbb/branch/master

.. image:: https://circleci.com/gh/scikit-build/cmake-python-distributions.svg?style=svg
    :target: https://circleci.com/gh/scikit-build/cmake-python-distributions

.. image:: https://travis-ci.org/scikit-build/cmake-python-distributions.svg?branch=master
    :target: https://travis-ci.org/scikit-build/cmake-python-distributions

`CMake <http://www.cmake.org>`_ is used to control the software compilation
process using simple platform and compiler independent configuration files, 
and generate native makefiles and workspaces that can be used in the
compiler environment of your choice.

The suite of CMake tools were created by Kitware in response to the need
for a powerful, cross-platform build environment for open-source projects
such as ITK and VTK.

The CMake python wheels provide `CMake 3.6.2 <https://cmake.org/cmake/help/v3.6/index.html>`_.

This project is maintained by Jean-Christophe Fillion-Robin from Kitware Inc.
It is covered by the `Apache License, Version 2.0 <http://www.apache.org/licenses/LICENSE-2.0>`_.

CMake is distributed under the OSI-approved BSD 3-clause License.
For more information about CMake, visit http://cmake.org

* Documentation: http://cmake-python-distributions.readthedocs.io/en/latest/
* Source code: https://github.com/scikit-build/cmake-python-distributions
* Mailing list: https://groups.google.com/forum/#!forum/scikit-build
